containertools.remove_leafless_containers_in_expr
=================================================

.. autofunction:: abjad.tools.containertools.remove_leafless_containers_in_expr.remove_leafless_containers_in_expr
   :noindex:
